Jupytools
=========

Convenience tools to simplify Jupyter development.

Features
--------

* Exporting Jupyter notebook cells annotated with `#export` commentary
* Automatically choose the implementation of `set_trace` function depending where the script is running
* Extend interpreter search path to include directories with additional utilities to import in notebook
